/*!
* eSM プラグインサンプル03 ver 1.0 
* 活動登録画面 進捗セレクトボックス制御スクリプト
* https://www.softbrain.co.jp/  
* Copyright (c) SOFTBRAIN Co.,Ltd.
*/

// APIトークン
var token = '96326b12-4b79-404e-bb8f-0aa90e1d99f8';
// eSMのコンテキストパスを取得 
var contextPath = window.location.protocol + '//' + window.location.host + '/' + document.URL.split('/')[3];
// リクエストRestAPIのパス
var restApiUrl = '/rest/v1/entity'; 

//checkInputをフック 
var origin = checkInput;
// checkInput関数を上書き
checkInput = function(){ 

    // 「進捗状況」セレクトボックスが存在し、かつ表示だった場合に処理実施
    var select = $('select[name=progress_code]');
    if(select != null && select.css('display') != 'none') {
        //「登録」ボタン押下時に無効化解除
        select.prop('disabled', false);
    } 

    //オリジナルのcheckInputを呼び出す 
    return origin.apply(null, arguments); 
} 
 
/** 
 * ページロード時のイベント処理
 *
 * 活動登録画面で選択された顧客のランクが「D(4)」の場合に、
 * 進捗セレクトボックスを入力不可とする 
 */ 
$(document).ready(function(){ 
    // 顧客セレクトボックスから選択中のセールスコードを取得
    var salesCode = -1; 
    if($('select[name=sales_code_parent]').size()) { // 案件権限がない場合
        salesCode = $('select[name=sales_code_parent]').val();
    } else if($('select[name=sales_code_sel_parent]').size()) { // 案件権限がある場合
        salesCode = $('select[name=sales_code_sel_parent]').val();
    } 
    // 顧客が未選択の場合は何もしない 
    if(salesCode == -1) {
        return; 
    }

    // 進捗状況セレクトボックスの無効化処理
    setSelectboxDisabled(salesCode); 
});

/** 
 * 進捗状況セレクトボックスの無効化判定(セールスコード)
 *  
 * @param salesCode セールスコード 
 */
function setSelectboxDisabled(salesCode) {
    // セールスコードが無効でない場合にRestAPI実行
    if(salesCode != -1) { 
        // 項目コード(顧客コード:216)
        var columncodes = 216;
        // RestAPIのURLの構築
        var urlStr = contextPath + restApiUrl + '?obj=business&id=' + salesCode + '&columncodes=' + columncodes;

        // RestAPIへリクエストを送信
        $.ajax({ 
            url:urlStr, // RestAPIのURL
            type:'GET', // HTTPメソッド
            headers: { // リクエストヘッダー 
                'X-Auth-API-Token' : token
            }, 
            dataType:'json', // 受信データタイプ 
            cache: false, // キャッシュを無効
            timespan:1000 // タイムアウト時間(msec)
        }).done(function(data){ 
            // レスポンスから顧客コードを取得
            var code = data.value.item_data[0].num;
            // 顧客ランクの取得及び進捗状況セレクトボックスの無効化判定 
            setSelectboxDisabledFromCompanyCode(code);
        }).fail(function(XMLHttpRequest, textStatus, errorThrown){
            // 問題が発生した場合は警告ダイアログ表示
            alert(errorThrown);
        }) 
    } 
}

/**
 * 進捗状況セレクトボックスの無効化判定(顧客コード)
 *
 * @param companyCode 顧客コード
 */
function setSelectboxDisabledFromCompanyCode(companyCode) {

    // カンパニーコードが無効でない場合にRestAPI実行 
    if(companyCode != -1) { 
        // 項目コード(顧客ランク:339)
        var columncodes = 339; 
        // RestAPIのURLの構築 
        var urlStr = contextPath + restApiUrl + '?obj=customer&id=' + companyCode + '&columncodes=' + columncodes;

        // RestAPIへリクエストを送信
        $.ajax({ 
            url:urlStr, // RestAPIのURL
            type:'GET', // HTTPメソッド
            headers: { // リクエストヘッダー 
                'X-Auth-API-Token' : token
            },
            dataType:'json', // 受信データタイプ
            cache: false, // キャッシュを無効
            timespan:1000 // タイムアウト時間(msec)
        }).done(function(data){
            // レスポンスから顧客ランクを取得
            var rank = data.value.item_data[0].num;

            // 顧客ランクが「D(4)」の場合はセレクトボックスを無効化
            if(rank == 4) {
                // 「進捗状況」セレクトボックスの取得
                var select = $('select[name=progress_code]');
                // 「進捗状況」セレクトボックスが存在し、かつ表示されている場合に処理実施
                if(select != null && select.css('display') != 'none') {
                    // 「進捗状況」セレクトボックスを無効化
                    select.prop('disabled', true);
                    // 「進捗状況」セレクトボックスの文字色を変更(#aaa)
                    select.css('color','#aaa');
                }
            }
        }).fail(function(XMLHttpRequest, textStatus, errorThrown){  
            // 問題が発生した場合は警告ダイアログ表示
            alert(errorThrown);
        })
    } 
}  